==> org.apache.sling.api-2.9.1-20160202.171420-1714-sources.jar: org/apache/sling/spi/resource/provider/ProviderContext.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.sling.spi.resource.provider;

import javax.annotation.Nonnull;

import org.apache.sling.api.resource.util.PathSet;

import aQute.bnd.annotation.ProviderType;

/**
 * The provider context...
 */
@ProviderType
public interface ProviderContext {

    long OBSERVATION_LISTENER_CHANGED = 1;
    long EXCLUDED_PATHS_CHANGED       = 2;

    /**
     * Get the observation reporter for this instance.
     * @return The observation reporter.
     */
    @Nonnull ObservationReporter getObservationReporter();

    /**
     * Set of paths which are "hidden" by other resource providers.
     * @return A set of paths. The set might be empty
     */
    PathSet getExcludedPaths();
}

==> org.apache.sling.api-2.13.1-20160721.093457-44-sources.jar: org/apache/sling/spi/resource/provider/ProviderContext.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.sling.spi.resource.provider;

import javax.annotation.Nonnull;

import org.apache.sling.api.resource.path.PathSet;

import aQute.bnd.annotation.ProviderType;

/**
 * The provider context...
 *
 * @since 1.0.0 (Sling API Bundle 2.11.0)
 */
@ProviderType
public interface ProviderContext {

    long OBSERVATION_LISTENER_CHANGED = 1;
    long EXCLUDED_PATHS_CHANGED       = 2;

    /**
     * Get the observation reporter for this instance.
     * @return The observation reporter.
     */
    @Nonnull ObservationReporter getObservationReporter();

    /**
     * Set of paths which are "hidden" by other resource providers.
     * @return A set of paths. The set might be empty
     */
    PathSet getExcludedPaths();
}
